==> print-manager-4.10.5.tar.xz: print-manager-4.10.5/libkcups/KCupsPasswordDialog.h <==
/***************************************************************************
 *   Copyright (C) 2010-2012 by Daniel Nicoletti                           *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef KCUPSPASSWORDDIALOG_H
#define KCUPSPASSWORDDIALOG_H

#include <QObject>

class KCupsPasswordDialog : public QObject
{
    Q_OBJECT
public:
    KCupsPasswordDialog(QObject *parent = 0);

public slots:
    void exec(const QString &username, bool wrongPassword);

    bool accepted() const;
    QString username() const;
    QString password() const;

private:
    bool m_accepted;
    QString m_username;
    QString m_password;
};

#endif // KCUPSPASSWORDDIALOG_H

==> print-manager-15.04.2.tar.xz: print-manager-15.04.2/libkcups/KCupsPasswordDialog.h <==
/***************************************************************************
 *   Copyright (C) 2010-2012 by Daniel Nicoletti                           *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef KCUPSPASSWORDDIALOG_H
#define KCUPSPASSWORDDIALOG_H

#include <QObject>
#include <QWidget>

class KCupsPasswordDialog : public QObject
{
    Q_OBJECT
public:
    explicit KCupsPasswordDialog(QObject *parent = 0);
    void setMainWindow(WId mainwindow);

public slots:
    void exec(const QString &username, bool wrongPassword);

    bool accepted() const;
    QString username() const;
    QString password() const;

private:
    bool m_accepted;
    WId m_mainwindow;
    QString m_username;
    QString m_password;
};

#endif // KCUPSPASSWORDDIALOG_H
